summaryrefslogtreecommitdiffstats
path: root/kioslave/thumbnail/htmlcreator.cpp
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:33:34 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:33:34 +0000
commitc663b6440964f6ac48027143ac9e63298991f9d0 (patch)
tree6d8b0c5a5f9db1ee16acf98b1397cea9126b281d /kioslave/thumbnail/htmlcreator.cpp
parenta061f7191beebb0e4a3b0c0a7c534ec5f22f2dc7 (diff)
downloadtdebase-c663b6440964f6ac48027143ac9e63298991f9d0.tar.gz
tdebase-c663b6440964f6ac48027143ac9e63298991f9d0.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdebase@1157639 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kioslave/thumbnail/htmlcreator.cpp')
-rw-r--r--kioslave/thumbnail/htmlcreator.cpp22
1 files changed, 11 insertions, 11 deletions
diff --git a/kioslave/thumbnail/htmlcreator.cpp b/kioslave/thumbnail/htmlcreator.cpp
index 0431bcf6e..c9ddf0204 100644
--- a/kioslave/thumbnail/htmlcreator.cpp
+++ b/kioslave/thumbnail/htmlcreator.cpp
@@ -19,9 +19,9 @@
*/
#include <time.h>
-#include <qpixmap.h>
-#include <qimage.h>
-#include <qpainter.h>
+#include <tqpixmap.h>
+#include <tqimage.h>
+#include <tqpainter.h>
#include <kapplication.h>
#include <khtml_part.h>
@@ -45,12 +45,12 @@ HTMLCreator::~HTMLCreator()
delete m_html;
}
-bool HTMLCreator::create(const QString &path, int width, int height, QImage &img)
+bool HTMLCreator::create(const TQString &path, int width, int height, TQImage &img)
{
if (!m_html)
{
m_html = new KHTMLPart;
- connect(m_html, SIGNAL(completed()), SLOT(slotCompleted()));
+ connect(m_html, TQT_SIGNAL(completed()), TQT_SLOT(slotCompleted()));
m_html->setJScriptEnabled(false);
m_html->setJavaEnabled(false);
m_html->setPluginsEnabled(false);
@@ -68,8 +68,8 @@ bool HTMLCreator::create(const QString &path, int width, int height, QImage &img
killTimer(t);
// render the HTML page on a bigger pixmap and use smoothScale,
- // looks better than directly scaling with the QPainter (malte)
- QPixmap pix;
+ // looks better than directly scaling with the TQPainter (malte)
+ TQPixmap pix;
if (width > 400 || height > 600)
{
if (height * 3 > width * 4)
@@ -81,13 +81,13 @@ bool HTMLCreator::create(const QString &path, int width, int height, QImage &img
pix.resize(400, 600);
// light-grey background, in case loadind the page failed
- pix.fill( QColor( 245, 245, 245 ) );
+ pix.fill( TQColor( 245, 245, 245 ) );
int borderX = pix.width() / width, borderY = pix.height() / height;
- QRect rc(borderX, borderY, pix.width() - borderX * 2,
+ TQRect rc(borderX, borderY, pix.width() - borderX * 2,
pix.height() - borderY * 2);
- QPainter p;
+ TQPainter p;
p.begin(&pix);
m_html->paint(&p, rc);
p.end();
@@ -99,7 +99,7 @@ bool HTMLCreator::create(const QString &path, int width, int height, QImage &img
return true;
}
-void HTMLCreator::timerEvent(QTimerEvent *)
+void HTMLCreator::timerEvent(TQTimerEvent *)
{
qApp->exit_loop();
}